"""Constants for wing loads models."""
#  This file is part of FAST-OAD_CS23 : A framework for rapid Overall Aircraft Design
#  Copyright (C) 2022  ONERA & ISAE-SUPAERO
#  FAST is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.

NB_POINTS_POINT_MASS = 5
# MUST BE AN EVEN NUMBER
POINT_MASS_SPAN_RATIO = 0.01

SUBMODEL_AEROSTRUCTURAL_LOADS = "submodel.loads.wings.aerostructural"
SUBMODEL_STRUCTURAL_LOADS = "submodel.loads.wings.structural"
SUBMODEL_AERODYNAMIC_LOADS = "submodel.loads.wings.aerodynamic"
